begin

$------- Part 1: Polarity of Potistive Current Flow -----------
convention positive_current_flow=inward
temperature temp=300

load_mesh mesh_inf=SiC_MOS.aps  suprem_import=yes
output sol_outf=MOS_BV.out
more_output impact_ionization=yes space_charge=yes

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

$  Define well and source doping profiles analytically

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$


$ Well
doping impurity=shal_dopant charge_type=acceptor max_conc=3e23  &&
  x_prof= ( 0.0, 4.0, 0.01, 0.01 )  &&
  y_prof= ( 29.0, 30.0, 0.0, 0.00 )
$ Retrograde
doping impurity=shal_dopant charge_type=acceptor max_conc=8e23  &&
  x_prof= ( 0.0, 4.0, 0.01, 0.01 )  &&
  y_prof= ( 29.0, 29.5, 0.0, 0.00 )
$ Source
doping impurity=shal_dopant charge_type=donor max_conc=1.e25  &&
  x_prof= ( 1.0, 3.0, 0.01, 0.01 )  &&
  y_prof= ( 29.8, 30.0, 0.0, 0.00 )
$ JFET
doping impurity=shal_dopant charge_type=donor max_conc=1.e23  &&
  x_prof= ( 0.0, 5.5, 0.01, 0.01 )  &&
  y_prof= ( 29.1, 30.0, 0.0, 0.00 )
$Body tie
doping impurity=shal_dopant charge_type=acceptor max_conc=1.e25  &&
  x_prof= ( 0.0, 1.0, 0.01, 0.01 )  &&
  y_prof= ( 29.8, 30.0, 0.0, 0.00 )

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

$  Do the material mapping

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$


suprem_property user_material_mapping = yes

suprem_to_apsys_material suprem_mater=26  apsys_mater=1
suprem_to_apsys_material suprem_mater=4 apsys_mater=3
suprem_to_apsys_material suprem_mater=1 apsys_mater=2

material_label_define label=4h_sic mater=   1
load_macro name=4h_sic mater=   1

material_label_define label=sio2 mater=   2
load_macro name= sio2 mater= 2

material_label_define label=poly mater=   3
load_macro name= poly mater= 3



$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$ Define the contacts
$
$ Substrate= 1
$ Gate= 2
$ Source= 3
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

suprem_contact num=1 xrange=(0.000000 10.000000)  yrange=(-9999.000000 &&
9999.000000) touch_mater=1 side=lower

suprem_contact num=2 xrange=(2.5 10.000000)  yrange=(-9999.000000 &&
9999.000000) touch_mater=3 side=upper

suprem_contact num=3 xrange=(0.0 1.4)  yrange=(-9999.000000 &&
9999.000000) touch_mater=1 side=upper

contact num=1
contact num=2
contact num=3


$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

$  Set the bulk mobility parameters
$  Adjust for a-axis =1/1.2 x c-axis values
$  Get proper c-axis mobility from mobility anisotropy dir_y factor_elec=1.2

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

low_field_mobility_model el_doping_dependence_model=arora &&
el_ar_d=0.0791 el_ar_umin=0.0033 el_ar_n=1.94E+23 el_ar_a=0.61


$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$


$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

$  Set the channel mobility parameters
$  Use optimized Lombardi coefficients based on Kimoto and Cooper

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$



mobility_xy elec_field_model=lombardi hole_field_model=lombardi &&
elec_lombardi_b=1.00E+06  elec_lombardi_alpha=2.2E+05 &&
elec_lombardi_beta=0.043 elec_lombardi_delta=8.0E+14 &&
dir=y factor_elec=1.2 mater=1




$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$  Set virtual minority carrier concentration to improve convergence
$  This is critical for wide-bandgap BV simulation
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

set_minority_carrier virtual_eg_kt=25



$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$
$   Impact ionization models for SiC
$   Choose coefficients from Loh et al, TED 2008
$   in this example
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

$  Originals from Crosslight Example
$impact_chynoweth mater = 1 hole_setnum = 1  &&
$    hole_set1 =  [1.12e+09,1.72e+09,1.]  &&
$    elec_setnum = 1 elec_set1 =  [4.60e+07,1.78e+09,1.]

$  Old Silvaco defaults
$impact_chynoweth mater = 1 hole_setnum = 1  &&
$    hole_set1 =  [5.18e+08,1.4e+09,1.]  &&
$    elec_setnum = 1 elec_set1 =  [1.660e+08,1.27e+09,1.]

$ Loh/GE Coefficinets
impact_chynoweth mater = 1 hole_setnum = 1  &&
   hole_set1 =  [3.51e+08,1.03e+09,1.09]  &&
    elec_setnum = 1 elec_set1 =  [2.78e+08,1.05e+09,1.37]


$ From Hatakeyama's paper  a axis coefficients
$impact_chynoweth mater = 1 hole_setnum = 1  &&
$   hole_set1 =  [2.96E+09,1.6E+09,1.]  &&
$   elec_setnum = 1 elec_set1 =  [2.1e9,1.7E+09,1.]


$ From Hatakeyama's paper  C axis coefficients
$impact_chynoweth mater = 1 hole_setnum = 1  &&
$    hole_set1 =  [3.41e+10,2.5E+09,1.]  &&
$    elec_setnum = 1 elec_set1 =  [1.76e+10,3.3E+09,1.]


$impact_lackner elec_a_coef=2.10E+09 elec_critical_field=1.7E+09 &&
$               hole_a_coef=2.96e+09 hole_critical_field=1.6E+09

$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$  Equilibrium solution
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$


newton_par damping_step=5. max_iter=150 &&
var_tol=0.1 res_tol=0.1
$
equilibrium
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
$
$  Reverse Simulation
$
$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$


newton_par damping_step=5.   &&
  var_tol=0.01 res_tol=0.01 change_variable=no



scan var=voltage_1 value_to=5000 &&
   init_step=0.01 max_step=50 min_step=1e-8 &&
   auto_finish=current_1 auto_until=0.1 auto_condition=above


scan var=current_1 value_to=10  &&
  init_step=1e-1 min_step=1.e-10 max_step=1.e1




end